"""
Configs migration

Generation datetime: 2022-07-14 12:49:26.928877
"""

from typing import List

from configs_core.migration.db_migrate_helper import DatabaseMigrationHelper, LimitationToModify

mh: DatabaseMigrationHelper

REVISION = "2a7da489"
DOWN_REVISION = "1c416fe4"


limitationsToModify: List[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_HANDLERS_LIVENESS_SETTINGS",
        oldValidationSchema={
            "type": "object",
            "properties": {"real_threshold": {"type": "number", "minimum": 0, "maximum": 1}},
            "description": "FSDK one shot liveness settings",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "real_threshold": {"type": "number", "minimum": 0, "maximum": 1},
                "quality_threshold": {"type": "number", "minimum": 0, "maximum": 1},
            },
            "description": "FSDK one shot liveness settings",
            "additionalProperties": False,
        },
        oldDefaultValue={"real_threshold": 0.5},
        newDefaultValue={"real_threshold": 0.5, "quality_threshold": 0.5},
        settingUpgradeFunction=lambda x: {**x, **{"quality_threshold": 0.5}},
        settingDowngradeFunction=lambda x: {k: v for k, v in x.items() if k != "quality_threshold"},
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-api", "luna-handlers"],
        newServices=["luna-api", "luna-handlers"],
    ),
]


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
