"""
Configs migration

Generation datetime: 2024-09-30 12:30:01.054039
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "aebc04c5"
DOWN_REVISION = "36b97d19"


limitationsToModify: list[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_LICENSES_ADDRESS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        oldDefaultValue={"origin": "http://127.0.0.1:5120", "api_version": 1},
        newDefaultValue={"origin": "http://127.0.0.1:5120", "api_version": 1},
        oldDescription="LUNA Licenses address",
        newDescription="LUNA Licenses address",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=lambda x: x,
        settingDowngradeFunction=lambda x: x,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-faces",
            "luna-lambda",
            "luna-remote-sdk",
            "luna-video-agent",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-faces",
            "luna-lambda",
            "luna-remote-sdk",
            "luna-video-agent",
            "luna-video-manager",
        ],
    ),
]

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
