"""Module contains classes for platform limits"""

from typing import Any, Dict


class _BaseLimits:
    """
    Base limits class
    """

    def asDict(self) -> Dict[str, Any]:
        """
        Get class dict
        Returns:
            dict with all not-protected class members
        """
        return {key: value for key, value in self.__dict__.items() if not key.startswith("_")}

    def __eq__(self, other) -> bool:
        """
        Operator equal

        Args:
            other: other settings

        Returns:
            True if dicts equals, otherwise False
        Raises:
            TypeError: if type 'other' is not _BaseLimits
        """
        if isinstance(other, _BaseLimits):
            return self.asDict() == other.asDict()
        raise TypeError(f"Got wrong type {type(other)}.")


class MatchLimits(_BaseLimits):
    """
    Matching limits
    Attributes:
        arrayFilterLimit (int): array filter limit
        referenceLimit (int): reference limit
        candidateLimit (int): candidate limit
        resultCandidateLimit (int): result candidate limit
    """

    def __init__(self, matchLimitsJson: Dict[str, int]):
        self.arrayFilterLimit = matchLimitsJson["array_filter_limit"]
        self.referenceLimit = matchLimitsJson["reference_limit"]
        self.candidateLimit = matchLimitsJson["candidate_limit"]
        self.resultCandidateLimit = matchLimitsJson["result_candidate_limit"]


class CrossMatchLimits(_BaseLimits):
    """
    Cross match limits
    Attributes:
        shortArrayFilterLimit (int): short array filter limit
        arrayFilterLimit (int): array filter limit
        resultCandidateLimit (int): result candidate limit
        generalLimit (int): general limit
    """

    def __init__(self, crossMatchLimitsJson: Dict[str, int]):
        self.shortArrayFilterLimit = crossMatchLimitsJson["short_array_filter_limit"]
        self.arrayFilterLimit = crossMatchLimitsJson["array_filter_limit"]
        self.resultCandidateLimit = crossMatchLimitsJson["result_candidate_limit"]
        self.generalLimit = crossMatchLimitsJson["general_limit"]
